about summary refs log tree commit diff
diff options
context:
space:
mode:
authorDaniel Micay <danielmicay@gmail.com>2013-02-01 01:17:50 -0500
committerDaniel Micay <danielmicay@gmail.com>2013-02-03 15:55:09 -0500
commit0a75aefad0e43e129fcba5e6c38fc9bbc620b952 (patch)
tree19841427962d3e2a12305fa932e5ca3d74bca6b2
parent2846e033d7eb961a5043a8cf5b8c6f516ba97b90 (diff)
downloadrust-0a75aefad0e43e129fcba5e6c38fc9bbc620b952.tar.gz
rust-0a75aefad0e43e129fcba5e6c38fc9bbc620b952.zip
update compile-fail/map-types.rs to use hashmap
-rw-r--r--src/test/compile-fail/map-types.rs14
1 files changed, 6 insertions, 8 deletions
diff --git a/src/test/compile-fail/map-types.rs b/src/test/compile-fail/map-types.rs
index 7161e854447..f829c730637 100644
--- a/src/test/compile-fail/map-types.rs
+++ b/src/test/compile-fail/map-types.rs
@@ -8,16 +8,14 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-extern mod std;
-use std::map;
-use std::map::HashMap;
-use std::map::StdMap;
+use core::container::Map;
+use core::hashmap::linear::LinearMap;
 
 // Test that trait types printed in error msgs include the type arguments.
 
 fn main() {
-    let x: StdMap<~str,~str> = map::HashMap::<~str,~str>() as
-        StdMap::<~str,~str>;
-    let y: StdMap<uint,~str> = x;
-    //~^ ERROR mismatched types: expected `@std::map::StdMap<uint,~str>`
+    let x: Map<~str, ~str> = LinearMap::new::<~str, ~str>() as
+        Map::<~str, ~str>;
+    let y: Map<uint, ~str> = x;
+    //~^ ERROR mismatched types: expected `@core::container::Map/&<uint,~str>`
 }